// anim.cpp
//
// Implementaiton for C3dAnimation


#include "stdafx.h"
#include "Stage.h"
#include "anim.h"

C3dAnimation::C3dAnimation()
{
	m_pIAnim = NULL;
	m_dLength = 0;
	m_dCurTime = 0;
}

// virtual
C3dAnimation::~C3dAnimation()
{
	if (m_pIAnim) m_pIAnim->Release();
}

BOOL C3dAnimation::Create(C3dFrame* pFrame)
{
	if (m_pIAnim) {
		m_pIAnim->Release();
		m_pIAnim = NULL;
	}
	m_hr = the3dEngine.GetInterface()->CreateAnimation(&m_pIAnim);
	if (FAILED(m_hr)) return FALSE;
	ASSERT(m_pIAnim);
	ASSERT(pFrame);
	m_pFrame = pFrame;
	m_hr = m_pIAnim->SetFrame(pFrame->GetInterface());
	ASSERT(SUCCEEDED(m_hr));
	m_dLength = 0;
	m_dCurTime = 0;
	return SetOptions(D3DRMANIMATION_CLOSED
					  | D3DRMANIMATION_POSITION
					  | D3DRMANIMATION_SPLINEPOSITION);
}

BOOL C3dAnimation::SetOptions(DWORD dwFlags)
{
	ASSERT(m_pIAnim);
	ASSERT(dwFlags & (D3DRMANIMATION_CLOSED | D3DRMANIMATION_OPEN));
	ASSERT(dwFlags & (D3DRMANIMATION_LINEARPOSITION | D3DRMANIMATION_SPLINEPOSITION));
	ASSERT(dwFlags & (D3DRMANIMATION_POSITION | D3DRMANIMATION_SCALEANDROTATION));
	m_hr = m_pIAnim->SetOptions(dwFlags);
	return SUCCEEDED(m_hr);
}


BOOL C3dAnimation::AddKey()
{
	if (!AddKey(m_dCurTime)) {
		return FALSE;
	}
	m_dCurTime += 1.0;
	return TRUE;
}

BOOL C3dAnimation::AddKey(double time)
{
	double x, y, z;
	ASSERT(m_pFrame);
	m_pFrame->GetPosition(x, y, z);
	ASSERT(m_pIAnim);
	m_hr = m_pIAnim->AddPositionKey(time, x, y, z);
	if (time > m_dLength) m_dLength = time;
	return SUCCEEDED(m_hr);
}

BOOL C3dAnimation::SetTime(double time)
{
	ASSERT(m_pIAnim);
	m_hr = m_pIAnim->SetTime(time);
	m_dCurTime = time;
	return SUCCEEDED(m_hr);
}

